---
title: Overview
aliases:
  - ../index.html
jupyter:
  kernelspec:
    display_name: Python 3 (ipykernel)
    language: python
    name: python3
---


The ShinyBroker intro video will be here soon, but until I shoot it and upload
it, here's a stand-in test video about Quartodocs, the package I'm using to
build the site.

Check out the below screencast for a walkthrough of creating a documentation
site, or read on for instructions -- it's a good platform :)


```{python}
#| echo: false
#| output: asis

# this code ensures that the proper html for the tutorial screencast is used,
# depending on whether it's being rendered for the github README, or doc site.
import os

if "BUILDING_README" in os.environ:
    # I don't know why, but we need to repeat the Installation header here.
    # or quarto makes it disappear when we generate the readme
    print("""
<p align="center">
<a href="https://www.loom.com/share/fb4eb736848e470b8409ba46b514e2ed">
<img src="https://cdn.loom.com/sessions/thumbnails/fb4eb736848e470b8409ba46b514e2ed-00001.gif" width="75%">
</a>
</p>

<br>

""")
else:
    print("""
<div style="position: relative; padding-bottom: 64.5933014354067%; height: 0;"><iframe src="https://www.loom.com/embed/fb4eb736848e470b8409ba46b514e2ed?sid=31db7652-43c6-4474-bab3-19dea2170775" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen style="position: absolute; top: 0; left: 0; width: 100%; height: 100%;"></iframe></div>
<br>
""")

```
